======================
TL2cgen Python Package
======================

|PyPI version|

.. |PyPI version| image:: https://badge.fury.io/py/tl2cgen.svg
   :target: http://badge.fury.io/py/tl2cgen

**TL2cgen** is a compiler for decision tree models: you can convert any decision tree models
(Random Forests, Gradient Boosting) into C code and compile it to a native binary.

See the documentation for more details.
